@@ -1,13 +1,14 @@
 import matplotlib.pyplot as plt
 
 
-def plot_explanation(original, explanation, prediction, ground_truth, save_path=None):
+def plot_explanation(original, explanation, prediction, confidence, ground_truth, save_path=None):
     """
     Plots the original image alongside the explanation.
 
     :param original: numpy array of shape (height, width, channels), original image
     :param explanation: numpy array of shape (height, width, channels), heatmap superimposed to original image
     :param prediction: string, name of predicted class
+    :param confidence: float, probability of predicted class
     :param ground_truth: string, name of true class
     :param save_path: path where to save the figure
     :return:
@@ -23,7 +24,8 @@ def plot_explanation(original, explanation, prediction, ground_truth, save_path=
     plt.imshow(explanation)
     plt.axis('off')
     plt.title('explanation')
-    plt.suptitle('Prediction: {}\nGround truth: {}'.format(prediction, ground_truth))
+    plt.suptitle('Prediction: {} (Confidence: {:.2f%})\nGround truth: {}'
+                 .format(prediction, ground_truth, confidence*100))
 
     if save_path is not None:
         plt.savefig(save_path)
